@@ -1,7 +1,9 @@
 package Acme::CPANModulesUtil::FeatureMatrix;
 
-our $DATE = '2019-01-12'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-02-20'; # DATE
+our $DIST = 'Acme-CPANModulesUtil-FeatureMatrix'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -59,6 +61,7 @@ sub draw_feature_matrix {
 
     # generate table and collect notes
     my @notes;
+    my %note_nums; # text => num
     my $note_num = 0;
     my @rows;
 
@@ -98,16 +101,24 @@ sub draw_feature_matrix {
                 }
                 my $fv = defined($f->{value}) ? ($f->{value} ? "yes" : "no") : "N/A";
                 my $has_note;
+                my $this_note_num;
                 if ($f->{summary}) {
                     $has_note++;
-                    $note_num++;
-                    my $note = "=item $note_num. $f->{summary}\n\n";
+
+                    my $note_text = $f->{summary};
                     if ($f->{description}) {
-                        $note .= Markdown::To::POD::markdown_to_pod($f->{description}) . "\n\n";
+                        $note_text .= Markdown::To::POD::markdown_to_pod($f->{description}) . "\n\n";
+                    }
+
+                    if ($this_note_num = $note_nums{$note_text}) {
+                        # reuse the same text from another note
+                    } else {
+                        $note_num++;
+                        push @notes, "=item $note_num. $note_text\n\n";
+                        $note_nums{$note_text} = $this_note_num = $note_num;
                     }
-                    push @notes, $note;
                 }
-                push @row, $fv . ($has_note ? " *$note_num)" : "");
+                push @row, $fv . ($has_note ? " *$this_note_num)" : "");
             }
             push @rows, \@row;
         }
@@ -143,7 +154,7 @@ Acme::CPANModulesUtil::FeatureMatrix - Draw features matrix of modules in an Acm
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModulesUtil::FeatureMatrix (from Perl distribution Acme-CPANModulesUtil-FeatureMatrix), released on 2019-01-12.
+This document describes version 0.003 of Acme::CPANModulesUtil::FeatureMatrix (from Perl distribution Acme-CPANModulesUtil-FeatureMatrix), released on 2021-02-20.
 
 =head1 FUNCTIONS
 
@@ -166,6 +177,7 @@ Arguments ('*' denotes required arguments):
 
 Name of Acme::CPANModules::* module, without the prefix.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -189,7 +201,7 @@ Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesUtil
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesUtil-FeatureMatrix>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModulesUtil-FeatureMatrix/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -205,7 +217,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
